==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/VsphereVirtualDiskVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class VsphereVirtualDiskVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource,io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceBuilder>{
  public VsphereVirtualDiskVolumeSourceBuilder() {
    this(false);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new VsphereVirtualDiskVolumeSource(), validationEnabled);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new VsphereVirtualDiskVolumeSource(), validationEnabled);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance) {
    this(fluent, instance, false);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFsType(instance.getFsType()); 
    fluent.withStoragePolicyID(instance.getStoragePolicyID()); 
    fluent.withStoragePolicyName(instance.getStoragePolicyName()); 
    fluent.withVolumePath(instance.getVolumePath()); 
    this.validationEnabled = validationEnabled; 
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance) {
    this(instance,false);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFsType(instance.getFsType()); 
    this.withStoragePolicyID(instance.getStoragePolicyID()); 
    this.withStoragePolicyName(instance.getStoragePolicyName()); 
    this.withVolumePath(instance.getVolumePath()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource build() {
    VsphereVirtualDiskVolumeSource buildable = new VsphereVirtualDiskVolumeSource(fluent.getFsType(),fluent.getStoragePolicyID(),fluent.getStoragePolicyName(),fluent.getVolumePath());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VsphereVirtualDiskVolumeSourceBuilder that = (VsphereVirtualDiskVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/VsphereVirtualDiskVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class VsphereVirtualDiskVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource,io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceBuilder>{
  public VsphereVirtualDiskVolumeSourceBuilder() {
    this(false);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new VsphereVirtualDiskVolumeSource(), validationEnabled);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new VsphereVirtualDiskVolumeSource(), validationEnabled);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance) {
    this(fluent, instance, false);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFsType(instance.getFsType()); 
    fluent.withStoragePolicyID(instance.getStoragePolicyID()); 
    fluent.withStoragePolicyName(instance.getStoragePolicyName()); 
    fluent.withVolumePath(instance.getVolumePath()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance) {
    this(instance,false);
  }
  public VsphereVirtualDiskVolumeSourceBuilder(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFsType(instance.getFsType()); 
    this.withStoragePolicyID(instance.getStoragePolicyID()); 
    this.withStoragePolicyName(instance.getStoragePolicyName()); 
    this.withVolumePath(instance.getVolumePath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource build() {
    VsphereVirtualDiskVolumeSource buildable = new VsphereVirtualDiskVolumeSource(fluent.getFsType(),fluent.getStoragePolicyID(),fluent.getStoragePolicyName(),fluent.getVolumePath());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VsphereVirtualDiskVolumeSourceBuilder that = (VsphereVirtualDiskVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
